<?php
session_start();
if (empty($_SESSION['custusername'])) {
    header("Location: login_form.php");
    exit();
}

// Database connection
require_once('mysqli_connect.php');

// Query for dynamic dropdown values
$query_item_no = "SELECT DISTINCT item_no FROM product ORDER BY item_no ASC";
$query_product_name = "SELECT DISTINCT product_name FROM product ORDER BY product_name ASC";
$query_product_type = "SELECT DISTINCT product_type FROM product ORDER BY product_type ASC";
$query_release_year = "SELECT DISTINCT release_year FROM product ORDER BY release_year ASC";

// Fetch results for dropdowns
$item_numbers = mysqli_query($dbc, $query_item_no);
$product_names = mysqli_query($dbc, $query_product_name);
$product_types = mysqli_query($dbc, $query_product_type);
$release_years = mysqli_query($dbc, $query_release_year);
?>

<!doctype html>
<html>
<head>
<style>
body {
    font-family: Arial, sans-serif;
    text-align: center;
    background-image: url('images/deathstar_background.png');
    background-size: cover;
    color: white;
}

.container {
    display: inline-block;
    margin-top: 20px;
    text-align: left;
    border: 1px solid #ccc;
    padding: 20px;
    border-radius: 10px;
    width: 50%;
    background-color: rgba(255, 255, 255, 0.8);
}

fieldset {
    border: 1px solid #300ACC;
    border-radius: 8px;
    padding: 10px;
    margin-bottom: 20px;
}

label {
    font-weight: bold;
    color: #300ACC;
    display: block;
    margin-bottom: 8px;
}

input[type="number"], select {
    width: 100%;
    padding: 8px;
    margin-bottom: 10px;
    box-sizing: border-box; /* Ensures padding doesn't cause the select element to overflow */
}

select {
    max-width: 300px; /* Limits the dropdown width to 300px */
}

input[type="submit"] {
    background-color: #300ACC;
    color: white;
    padding: 10px 20px;
    border: none;
    border-radius: 5px;
    cursor: pointer;
}

input[type="submit"]:hover {
    background-color: #4e3cff;
}

.center {
    text-align: center;
}

h1, h2 {
    color: white;
}
</style>
</head>
<body>
    <img src="images/lego_star_wars_ucs.jpg" width="400px" alt="LEGO UCS" style="display:block; margin: 0 auto;">
    <h1>Welcome, <?php echo htmlspecialchars($_SESSION['custusername']); ?>!</h1>
    <h2>Search the Ultimate Collector Series</h2>
    
    <div class="container">
        <form action="handle_search.php" method="post">
            <fieldset>
                <legend>Search Products</legend>

                <!-- Dropdowns -->
                <label for="item_no">Item Number:</label>
                <select name="item_no" id="item_no">
                    <option value="">--Select Item Number--</option>
                    <?php
                    while ($row = mysqli_fetch_assoc($item_numbers)) {
                        echo "<option value=\"" . $row['item_no'] . "\">" . $row['item_no'] . "</option>";
                    }
                    ?>
                </select>

                <label for="product_name">Product Name:</label>
                <select name="product_name" id="product_name">
                    <option value="">--Select Product Name--</option>
                    <?php
                    while ($row = mysqli_fetch_assoc($product_names)) {
                        echo "<option value=\"" . $row['product_name'] . "\">" . $row['product_name'] . "</option>";
                    }
                    ?>
                </select>

                <label for="product_type">Product Type:</label>
                <select name="product_type" id="product_type">
                    <option value="">--Select Product Type--</option>
                    <?php
                    while ($row = mysqli_fetch_assoc($product_types)) {
                        echo "<option value=\"" . $row['product_type'] . "\">" . $row['product_type'] . "</option>";
                    }
                    ?>
                </select>

                <label for="release_year">Release Year:</label>
                <select name="release_year" id="release_year">
                    <option value="">--Select Release Year--</option>
                    <?php
                    while ($row = mysqli_fetch_assoc($release_years)) {
                        echo "<option value=\"" . $row['release_year'] . "\">" . $row['release_year'] . "</option>";
                    }
                    ?>
                </select>

                <!-- Range Inputs -->
                <label for="pieces_min">Number of Pieces (Range):</label>
                <input type="number" name="pieces_min" id="pieces_min" placeholder="Min" min="1" max="15000">
                <input type="number" name="pieces_max" id="pieces_max" placeholder="Max" min="1" max="15000">

                <label for="price_min">Price (Range):</label>
                <input type="number" name="price_min" id="price_min" step="0.01" placeholder="Min" min="0.01" max="10000.00">
                <input type="number" name="price_max" id="price_max" step="0.01" placeholder="Max" min="0.01" max="10000.00">

                <input type="submit" value="Search">
            </fieldset>
        </form>
    </div>

    <button type="button" onclick="location.href='logout.php';" style="margin-top: 20px;">Log out</button>
</body>
</html>
