<?php
session_start();
if (empty($_SESSION['username'])) {
    header("Location: login_form.php");
    exit();
}

// Database connection
include('mysqli_connect.php');

// Fetch employee details
$username = $_SESSION['username'];
$query = "SELECT firstname, lastname FROM employees WHERE username = ?";
$stmt = $dbc->prepare($query);
$stmt->bind_param("s", $username);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows > 0) {
    $row = $result->fetch_assoc();
    $fullname = htmlspecialchars($row['firstname']) . " " . htmlspecialchars($row['lastname']);
} else {
    $fullname = "Employee"; // Default fallback if no data is found
}

echo "<h1 style='text-align: center;'>Welcome $fullname</h1>";

// Fetch dropdown options
$item_numbers = $dbc->query("SELECT DISTINCT item_no FROM product");
$product_names = $dbc->query("SELECT DISTINCT product_name FROM product");
$product_types = $dbc->query("SELECT DISTINCT product_type FROM product");
$release_years = $dbc->query("SELECT DISTINCT release_year FROM product");
?>
<!doctype html>
<html>
<head>
    <style>
        form { width: 80%; max-width: 600px; margin: 0 auto; }
        .product { margin: 20px auto; padding: 10px; border: 1px solid #ccc; text-align: center; }
        img { display: block; margin: 10px auto; max-width: 100%; }
    </style>
</head>
<body>
    
    <h2 style="color: orange; text-align: center;">This page is for employee use only!</h2>
    <p style="text-align: center;">
        
    
    <div class="container">
        <form action="" method="post">
            <fieldset>
                <legend>Search Products</legend>

                <!-- Dropdowns -->
                <label for="item_no">Item Number:</label>
                <select name="item_no" id="item_no">
                    <option value="">--Select Item Number--</option>
                    <?php while ($row = $item_numbers->fetch_assoc()) { ?>
                        <option value="<?= htmlspecialchars($row['item_no']) ?>"><?= htmlspecialchars($row['item_no']) ?></option>
                    <?php } ?>
                </select>
                <br><br>
                <label for="product_name">Product Name:</label>
                <select name="product_name" id="product_name">
                    <option value="">--Select Product Name--</option>
                    <?php while ($row = $product_names->fetch_assoc()) { ?>
                        <option value="<?= htmlspecialchars($row['product_name']) ?>"><?= htmlspecialchars($row['product_name']) ?></option>
                    <?php } ?>
                </select>
                <br><br>
                <label for="product_type">Product Type:</label>
                <select name="product_type" id="product_type">
                    <option value="">--Select Product Type--</option>
                    <?php while ($row = $product_types->fetch_assoc()) { ?>
                        <option value="<?= htmlspecialchars($row['product_type']) ?>"><?= htmlspecialchars($row['product_type']) ?></option>
                    <?php } ?>
                </select>
                <br><br>
                <label for="release_year">Release Year:</label>
                <select name="release_year" id="release_year">
                    <option value="">--Select Release Year--</option>
                    <?php while ($row = $release_years->fetch_assoc()) { ?>
                        <option value="<?= htmlspecialchars($row['release_year']) ?>"><?= htmlspecialchars($row['release_year']) ?></option>
                    <?php } ?>
                </select>
                <br><br>
                <!-- Range Inputs -->
                <label for="pieces_min">Number of Pieces (Range):</label>
                <input type="number" name="pieces_min" id="pieces_min" placeholder="Min" min="1" max="15,000">
                <input type="number" name="pieces_max" id="pieces_max" placeholder="Max" min="1" max="15,000">
                <br><br>
                <label for="price_min">Price (Range):</label>
                <input type="number" name="price_min" id="price_min" step="0.01" placeholder="Min" min="0.01" max="10,000">
                <input type="number" name="price_max" id="price_max" step="0.01" placeholder="Max" min="0.01" max="10,000">
                <br><br>
                <input type="submit" value="Search">
            </fieldset>
        </form>
    </div>
        <p style="text-align: center;">
        <button type="button" onclick="location.href='logout.php';">Log out</button>
    </p>
    <?php
    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        $query = "SELECT * FROM product WHERE 1";
        $conditions = [];
        $params = [];
        $types = '';

        // Dynamic conditions
        if (!empty($_POST['item_no'])) {
            $conditions[] = "item_no = ?";
            $params[] = $_POST['item_no'];
            $types .= 's';
        }
        if (!empty($_POST['product_name'])) {
            $conditions[] = "product_name LIKE ?";
            $params[] = '%' . $_POST['product_name'] . '%';
            $types .= 's';
        }
        if (!empty($_POST['product_type'])) {
            $conditions[] = "product_type = ?";
            $params[] = $_POST['product_type'];
            $types .= 's';
        }
        if (!empty($_POST['release_year'])) {
            $conditions[] = "release_year = ?";
            $params[] = $_POST['release_year'];
            $types .= 'i';
        }
        if (!empty($_POST['pieces_min']) || !empty($_POST['pieces_max'])) {
            $conditions[] = "number_pieces BETWEEN ? AND ?";
            $params[] = $_POST['pieces_min'] ?: 1;
            $params[] = $_POST['pieces_max'] ?: 15000;
            $types .= 'ii';
        }
        if (!empty($_POST['price_min']) || !empty($_POST['price_max'])) {
            $conditions[] = "price BETWEEN ? AND ?";
            $params[] = $_POST['price_min'] ?: 0.01;
            $params[] = $_POST['price_max'] ?: 10000.00;
            $types .= 'dd';
        }

        if ($conditions) {
            $query .= ' AND ' . implode(' AND ', $conditions);
        }

        $stmt = $dbc->prepare($query);
        if ($types) {
            $stmt->bind_param($types, ...$params);
        }
        $stmt->execute();
        $result = $stmt->get_result();

        if ($result->num_rows > 0) {
    echo "<h2>Search Results</h2>";
    while ($row = $result->fetch_assoc()) {
        echo "<div class='product'>";
        echo "<h3>" . htmlspecialchars($row['product_name']) . " (" . htmlspecialchars($row['item_no']) . ")</h3>";
        echo "<p><strong>Type:</strong> " . htmlspecialchars($row['product_type']) . "</p>";
        echo "<p><strong>Release Year:</strong> " . htmlspecialchars($row['release_year']) . "</p>";
        echo "<p><strong>Price:</strong> $" . htmlspecialchars($row['price']) . "</p>";
        echo "<p><strong>Number of Pieces:</strong> " . htmlspecialchars($row['number_pieces']) . "</p>";
        // Adding Quantity on Hand and Image here:
        echo "<p><strong>Quantity on Hand:</strong> " . htmlspecialchars($row['qty']) . "</p>";
        echo "<img src='" . (filter_var($row['image_url'], FILTER_VALIDATE_URL) ? htmlspecialchars($row['image_url']) : 'images/placeholder.jpg') . "' alt='Product Image'>";
        echo "</div>";
    }
} else {
    echo "<p>No products found matching your criteria.</p>";
}
    }

    $dbc->close();
    ?>
    
</body>
</html>

